@@ -805,18 +805,15 @@ class Shopware6AdminAPIClientBase(object):
 
         see https://shopware.stoplight.io/docs/admin-api/ZG9jOjEwODA3NjQx-authentication-and-authorisation
         setup via Web Administration Interface > settings > system > integration: "access_id" and "access_secret"
-        or directly via URL : https://<fqdn>/admin#/sw/integration/index
-        were <fqdn> is the fully qualified domain name, like https://myshop.mydomain.com/admin#/sw/integration/index
+        or directly via URL : https://shop.yourdomain.com/admin#/sw/integration/index
 
         :parameter
             self.shopware_api_url   the api url, like : 'https://shop.yourdomain.com/api'
             self.client_id          the client ID, setup via Web Administration Interface > settings > system > integration: "access_id"
-                                    or directly via URL : https://<fqdn>/admin#/sw/integration/index
-                                    were <fqdn> is the fully qualified domain name, like https://myshop.mydomain.com/admin#/sw/integration/index
+                                    or directly via URL : https://shop.yourdomain.com/admin#/sw/integration/index
 
             self.client_secret      the client secret, setup via Web Administration Interface > settings > system > integration: "access_secret"
-                                    or directly via URL : https://<fqdn>/admin#/sw/integration/index
-                                    were <fqdn> is the fully qualified domain name, like https://myshop.mydomain.com/admin#/sw/integration/index
+                                    or directly via URL : https://shop.yourdomain.com/admin#/sw/integration/index
 
         :returns
             self.token
